# from .client import Client
# from .models.base import Base
#
#
# def login(username: str, password: str):
#     client = Client()
#     client.password_auth(username, password)
#     Base.client = client
